{% extends "vng_api_common/master.html" %}
{% load markup_tags %}

{% block content %}

  <div class="px-3 py-3 pt-md-5 pb-md-4 mx-auto text-center">
    <h1 class="display-4">{{ settings.PROJECT_NAME }} scopes</h1>
    <p class="lead">{{ settings.SITE_TITLE }}</p>
  </div>

  <div class="container">

    <p>
      Scopes worden typisch per component gedefinieerd en geven aan welke
      rechten er mogelijk zijn en in de context van een JWT geven ze aan welke
      rechten iemand heeft of wil verkrijgen.
    </p>

    {% for scope in scopes %}
      <a name="{{ scope.label }}"></a>
      <h2>{{ scope.label }}</h2>

      <p><strong>Scope</strong></p>
      <p>
        <code>{{ scope.label }}</code>
      </p>

      <p>
        {{ scope.description|default:""|apply_markup:"markdown" }}
      </p>
    {% endfor %}

  </div>

{% endblock content %}
