  <div class="col-sm-4">

    <div class="card">
      <div class="card-body">
        <h5 class="card-title"><i class="fas fa-bullhorn"></i> Notificaties</h5>
        <p class="card-text">Gebeurtenissen waarover dit component notificaties verstuurt.</p>
        <a href="{% url 'notifications:kanalen' %}" class="btn btn-primary">Notificaties</a>
      </div>
    </div>

  </div>

