# Generated by Django 2.0.13 on 2019-04-17 11:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('vng_api_common', '0002_apicredential'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='apicredential',
            options={'verbose_name': 'external API credential', 'verbose_name_plural': 'external API credentials'},
        ),
        migrations.AlterModelOptions(
            name='jwtsecret',
            options={'verbose_name': 'client credential', 'verbose_name_plural': 'client credentials'},
        ),
        migrations.AddField(
            model_name='apicredential',
            name='label',
            field=models.CharField(default='', help_text='human readable label', max_length=100, verbose_name='label'),
        ),
    ]
